Produces an ij matrix defining the proportion of the population using an ITN from distribution i on day j. Final column represents population with no ITN.
Arguments
- days
Vector of days on which ITN distribution events occur (required when continuous_distribution = FALSE)
- coverages
Vector detailing the proportion of the population receiving an ITN during each intervention (required when continuous_distribution = FALSE)
- retention
Average number of days a net is kept for
- n_days
Length of simulation
- distribution_type
Either 'random' or 'correlated'